pub enum EntTypeData {
Concrete {
ty: &'static str,
},
Wrapper {
ty: &'static str,
wrapped_tys: HashSet<&'static str>,
},
}Expand description
Represents data about an ent type
Variants
Concrete
Indicates an ent is a concrete type with the given static str being unique to its type
Wrapper
Indicates an ent is a wrapper around other ent types with the given static slice of static strs representing the types it wraps