Primitive

Enum Primitive 

pub enum Primitive {
    Bool(bool),
    Char(char),
    Number(Number),
    Unit,
}
Represents a primitive value

Variants



Bool(bool)



Char(char)



Number(Number)



Unit

Implementations

Source

impl Primitive

pub fn is_type(&self, type: PrimitiveType) -> bool

Returns true if this value is of the specified type

pub fn to_type(&self) -> PrimitiveType

Returns the type of this value

pub fn has_same_type(&self, other: &Primitive) -> bool

Returns true if this value and the other value are of the same type