Value

Enum Value 

pub enum Value {
    List(Vec<Value>),
    Map(HashMap<String, Value>),
    Optional(Option<Box<Value>>),
    Primitive(Primitive),
    Text(String),
}
Represents either a primitive or complex value

Variants



List(Vec<Value>)



Map(HashMap<String, Value>)



Optional(Option<Box<Value>>)



Primitive(Primitive)



Text(String)

Implementations

Source

impl Value

pub fn is_type(&self, type: ValueType) -> bool

Returns true if this value is of the specified type

pub fn to_type(&self) -> ValueType

Returns the type of this value

pub fn has_same_type(&self, other: &Value) -> bool

Returns true if this value and the other value are of the same type

pub fn is_complex(&self) -> bool

Returns true if not representing a primitive value

pub fn is_primitive(&self) -> bool

Returns true if representing a primitive value

pub fn to_primitive(&self) -> Option<Primitive>

Converts into underlying primitive value if representing one

pub fn to_primitive_type(&self) -> Option<PrimitiveType>

Converts into underlying primitive type if representing one